.. Letterboxd documentation master file, created by
   sphinx-quickstart on Mon Jun 25 08:01:15 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Letterboxd python API wrapper documentation
===========================================

This software is very much in an alpha state, and things that are working now may break in the future. Developer beware.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
